Index: /CKEditor/trunk/CHANGES.html
===================================================================
--- /CKEditor/trunk/CHANGES.html	(revision 5939)
+++ /CKEditor/trunk/CHANGES.html	(revision 5940)
@@ -63,4 +63,5 @@
 		<li><a href="http://dev.ckeditor.com/ticket/5399">#5399</a> : Lists pasted from Word do not maintain their nesting.</li>
 		<li><a href="http://dev.ckeditor.com/ticket/6225">#6225</a> : [FF] Can not transform sevaral lines to list with enterMode BR.</li>
+		<li><a href="http://dev.ckeditor.com/ticket/6467">#6467</a> : [FF] It is now possible to disable the plugin command on "mode" event.</li>
 		<li>Updated the following language files:<ul>
 			<li><a href="http://dev.ckeditor.com/ticket/6427">#6427</a> : Ukrainian;</li>
Index: /CKEditor/trunk/_source/plugins/maximize/plugin.js
===================================================================
--- /CKEditor/trunk/_source/plugins/maximize/plugin.js	(revision 5939)
+++ /CKEditor/trunk/_source/plugins/maximize/plugin.js	(revision 5940)
@@ -334,8 +334,9 @@
 				} );
 
 			// Restore the command state after mode change.
 			editor.on( 'mode', function()
 				{
-					editor.getCommand( 'maximize' ).setState( savedState );
+					var command = editor.getCommand( 'maximize' );
+					command.setState( command.state == CKEDITOR.TRISTATE_DISABLED ? CKEDITOR.TRISTATE_DISABLED : savedState );
 				}, null, null, 100 );
 		}
@@ -334,8 +334,9 @@
 				} );
 
-			// Restore the command state after mode change.
+			// Restore the command state after mode change, unless it has been changed to disabled (#6467)
 			editor.on( 'mode', function()
 				{
